@@ -6,7 +6,10 @@ Few extensions on `pymarc.Record` to make certain checks
 and manipulations a bit easier.
 """
 
-import collections
+try:
+    from collections.abc import Iterable  # noqa
+except ImportError:
+    from collections import Iterable  # noqa
 import itertools
 import re
 import warnings
@@ -16,11 +19,11 @@ import jsonpath_rw as jpath
 import pymarc
 from past.builtins import basestring
 
-__version__ = '0.2.1'
+__version__ = '0.2.12'
 
 __all__ = [
     'Record',
-    'FatRecord',  # Deprecated, will be removed soon.
+    'FatRecord',  # Deprecated, use Record instead.
     'marcdoc',
     'valuegetter',
     'fieldgetter',
@@ -114,9 +117,9 @@ def valuegetter(*fieldspecs, **kwargs):
 
     Example:
 
-    >>> from marcx import FatRecord, valuegetter
+    >>> from marcx import Record, valuegetter
     >>> from urllib import urlopen
-    >>> record = FatRecord(data=urlopen("http://goo.gl/lfJnw9").read())
+    >>> record = Record(data=urlopen("http://goo.gl/lfJnw9").read())
 
     In two steps:
 
@@ -141,7 +144,7 @@ def valuegetter(*fieldspecs, **kwargs):
     >>> set(valuegetter('002')(record))
     set([])
 
-    @see also: `FatRecord.itervalues`
+    @see also: `Record.itervalues`
     """
     combine_subfields = kwargs.get('combine_subfields', False)
     pattern = r'(?P<field>[^.]+)(.(?P<subfield>[^.]+))?'
@@ -212,20 +215,21 @@ class Record(pymarc.Record):
 
     def __init__(self, *args, **kwargs):
         super(Record, self).__init__(*args, **kwargs)
+        self.strict = True
 
     @classmethod
     def from_record(cls, record):
         """
-        Factory methods to create FatRecord from pymarc.Record object.
+        Factory methods to create Record from pymarc.Record object.
         """
         if not isinstance(record, pymarc.Record):
             raise TypeError('record must be of type pymarc.Record')
-        record.__class__ = FatRecord
+        record.__class__ = Record
         return record
 
     def to_record(self):
         """
-        Convert FatRecord to a pymarc.Record class. This is partially
+        Convert Record to a pymarc.Record class. This is partially
         addressed in https://github.com/edsu/pymarc/pull/36.
         """
         self.__class__ = pymarc.Record
@@ -237,6 +241,9 @@ class Record(pymarc.Record):
 
         marc.add('020', a='0201657880', z='0201802398')
         """
+        if tag.startswith("00") and (data is None or data == "") and not self.strict:
+            return
+
         if data:
             if indicators:
                 raise ValueError(Record.E_NO_INDICATORS)
@@ -260,22 +267,34 @@ class Record(pymarc.Record):
         if data:  # == control field (001 -- 009)
             field = pymarc.Field(tag, data=data)
         else:     # == non-control field (010 -- 999)
-            subfields = []
-            for key, value in kwargs.items():
-                if value is None:
-                    continue
-                key = key.replace('_', '')
-                if isinstance(value, basestring):
-                    if value == "":
+            if 'subfields' in kwargs:
+                sfs = kwargs['subfields']
+                subfields = [v for sl in [(a, b) for a, b in zip(sfs[::2], sfs[1::2]) if b] for v in sl]
+            else:
+                subfields = []
+                for key, value in kwargs.items():
+                    if value is None:
                         continue
-                    subfields += [key, value]
-                elif isinstance(value, collections.Iterable):
-                    for val in value:
-                        if not isinstance(val, basestring):
-                            raise ValueError('subfield values must be strings')
-                        subfields += [key, val]
+                    key = key.replace('_', '')
+                    if isinstance(value, basestring):
+                        if value == "":
+                            continue
+                        subfields += [key, value]
+                    elif isinstance(value, Iterable):
+                        for val in value:
+                            if not isinstance(val, basestring):
+                                raise ValueError('subfield values must be strings')
+                            if val:
+                                subfields += [key, val]
+                    else:
+                        raise ValueError('subfield values must be strings')
+
+            if not any(subfields[1::2]):
+                if self.strict:
+                    raise ValueError('none of the subfields contains a value')
                 else:
-                    raise ValueError('subfield values must be strings')
+                    return
+
             field = pymarc.Field(tag, indicators, subfields=subfields)
         self.add_field(field)
 
@@ -328,9 +347,16 @@ class Record(pymarc.Record):
         """
         return valuegetter(*fieldspecs, **kwargs)(self)
 
+    def values(self, *fieldspecs, **kwargs):
+        """
+        Turn generator from itervalues into list.
+        """
+        return list(self.itervalues(*fieldspecs, **kwargs))
+
     def iterfields(self, *fieldspecs):
         """
-        Shortcut for `fieldgetter(*fieldspecs)(self)`
+        Shortcut for `fieldgetter(*fieldspecs)(self)`; we do not add fields
+        methods, since that attribute is used already by pymarc.Record.
         """
         return fieldgetter(*fieldspecs)(self)
 
@@ -361,7 +387,7 @@ class Record(pymarc.Record):
         If there are multiple fields with the same tag,
         only the fields that match are removed, e.g.:
 
-        >>> record = FatRecord()
+        >>> record = Record()
         >>> record.add('020', a='97811111111')
         >>> record.add('020', a='11111111')
         >>> rmvd = record.remove_field_if('020.a', _startswith('978'))
